@@ -59,6 +59,8 @@ public:
         PeakBrightnessOverride,
         OutputNameRole,
         EdrPolicyRole,
+        BitsPerColorOptionsPreferEfficiencyRole,
+        BitsPerColorOptionsPreferAccuracyRole,
     };
     Q_ENUM(OutputRoles)
 
