@@ -5,10 +5,10 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "config.h"
-#include "../common/control.h"
+#include "common/control.h"
+#include "common/kscreen_daemon_debug.h"
+#include "common/output.h"
 #include "device.h"
-#include "kscreen_daemon_debug.h"
-#include "output.h"
 
 #include <QDir>
 #include <QFile>
